from chipwhisperer.common.utils import pluginmanager
from .base import ScopeTemplate
from chipwhisperer.common.utils.pluginmanager import Plugin

class USRPInterface(ScopeTemplate, Plugin):
    _name = "USRP"

    def __init__(self):
        super(USRPInterface, self).__init__()

        scopes = pluginmanager.getPluginsInDictFromPackage("chipwhisperer.capture.scopes.usrp_interface", True, False)

        self.getParams().addChildren([
            {'name':'Scope Type', 'key':'type', 'type':'list', 'values':scopes, 'value':scopes['USRP'], 'action':self.setCurrentScope_act}
        ])
        self.scopetype = None
        self.advancedSettings = None
        self.setCurrentScope(self.findParam('type').getValue())

    def setCurrentScope_act(self, param):
        self.setCurrentScope(param.getValue())

    def setCurrentScope(self, scope):
        self.scopetype = scope
        if scope is not None:
            self.scopetype.dataUpdated.connect(self.newDataReceived)
            self.params.append(self.scopetype.getParams())

    def _con(self):
        if self.scopetype is not None:
            self.scopetype.con()
            return True
        return False

    def _dis(self):
        if self.scopetype is not None:
            self.scopetype.dis()
        return True

    def arm(self):
        try:
            self.scopetype.arm()
        except:
            self.dis()
            raise

    def capture(self):
        """Raises IOError if unknown failure, returns 'False' if successful, 'True' if timeout"""
        return self.scopetype.capture()
